using System;
using System.Runtime.InteropServices;

/// <summary>
/// EPX-30SC API library definitions
/// </summary>
public class EPX30SC
{

	//
	// Device status (Return codes)
	//
    public const int EPX30SC_OK = 0;
    public const int EPX30SC_INVALID_HANDLE = 1;
    public const int EPX30SC_DEVICE_NOT_FOUND = 2;
    public const int EPX30SC_DEVICE_NOT_OPENED = 3;
    public const int EPX30SC_OTHER_ERROR = 4;
    public const int EPX30SC_COMMUNICATION_ERROR = 5;
    public const int EPX30SC_INVALID_PARAMETER = 6;

	//
	// Counter Mode
	//
	public const byte EPX30SC_CNT_MODE_1PHASE = 0;
	public const byte EPX30SC_CNT_MODE_2PHASE = 1;

	//
	// Counter Direction
	//
	public const byte EPX30SC_CNT_DIR_UP = 0;
	public const byte EPX30SC_CNT_DIR_DOWN = 1;

	//
	// Counter Control
	//
	public const byte EPX30SC_CNT_DISABLE = 0;
	public const byte EPX30SC_CNT_ENABLE = 1;

	//
	// Counter Status
	//

	public const byte EPX30SC_CNT_OK = 0;
	public const byte EPX30SC_CNT_OVF = 1;
	public const byte EPX30SC_CNT_UDF = 2;

	//
	// Counter External Control
	//
	public const byte EPX30SC_CNT_EX_DISABLE = 0;
	public const byte EPX30SC_CNT_EX_ENABLE = 1;

	//
	// Counter Latch Flag
	//
	public const byte EPX30SC_CNT_LAT_FALSE = 0;
	public const byte EPX30SC_CNT_LAT_TRUE = 1;


	//
	// I/O Port
	//
    public const byte EPX30SC_PORT0 = 0;
    public const byte EPX30SC_PORT1 = 1;
    public const byte EPX30SC_PORT2 = 2;
    public const byte EPX30SC_PORT3 = 3;

	//
	// Port Direction
	//
    public const byte EPX30SC_PORT_DIR_INPUT = 0;
    public const byte EPX30SC_PORT_DIR_OUTPUT = 1;


	//
	// Device Functions
	//
    [DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_GetNumberOfDevices (ref int Number);
    [DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_GetSerialNumber (int Index, ref int SerialNumber);
    [DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_Open (ref System.IntPtr Handle);
    [DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_OpenBySerialNumber (int SerialNumber, ref System.IntPtr Handle);
    [DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_Close (System.IntPtr Handle);

 	//
	// Counter Functions
	//
    [DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_SetCounterMode (System.IntPtr Handle, byte Mode);
    [DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_GetCounterMode (System.IntPtr Handle, ref byte Mode);
    [DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_SetCounterDirection (System.IntPtr Handle, byte Direction);
    [DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_GetCounterDirection (System.IntPtr Handle, ref byte Direction);
    [DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_SetCounterControl (System.IntPtr Handle, byte Control);
    [DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_GetCounterControl (System.IntPtr Handle, ref byte Control);
    [DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_ResetCounter (System.IntPtr Handle);
    [DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_GetCounterValue (System.IntPtr Handle, ref int Value);
    [DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_GetCounterStatus (System.IntPtr Handle, ref byte Status);
    [DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_GetCounterExControl (System.IntPtr Handle, ref byte Control);
    [DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_GetCounterLatchFlag (System.IntPtr Handle, ref byte Flag);
    [DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_GetCounterLatchValue (System.IntPtr Handle, ref int Value);

 	//
	// I/O Port Functions
	//
	[DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_SetPortDirection (System.IntPtr Handle, byte Port, byte Direction);
    [DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_GetPortDirection (System.IntPtr Handle, byte Port, ref byte Direction);
    [DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_OutputPort (System.IntPtr Handle, byte Port, byte Value);
    [DllImport("EPX30SC.dll")]
    public static extern int EPX30SC_InputPort (System.IntPtr Handle, byte Port, ref byte Value);

}
