/*++

Copyright (c) 2012-2013 ELMOS Co., Ltd.

Module Name:
	EPX30SC.h
Abstract:
	EPX-30SC API library definitions
Revision History:
	12/09/21	Created.
	13/05/01	Support for Windows 8.

--*/

#ifndef EPX30SC_H
#define EPX30SC_H

#ifdef EPX30SC_EXPORTS_
#define EPX30SC_API __declspec(dllexport)
#else
#define EPX30SC_API __declspec(dllimport)
#endif

//
// Device handle
//
typedef void *EPX30SC_HANDLE;

//
// Device status (Return Value)
//
enum {
	EPX30SC_OK,
	EPX30SC_INVALID_HANDLE,
	EPX30SC_DEVICE_NOT_FOUND,
	EPX30SC_DEVICE_NOT_OPENED,
	EPX30SC_OTHER_ERROR,
	EPX30SC_COMMUNICATION_ERROR,
	EPX30SC_INVALID_PARAMETER
};

//
// Counter Mode
//
#define EPX30SC_CNT_MODE_1PHASE	0
#define EPX30SC_CNT_MODE_2PHASE	1

//
// Counter Direction
//
#define EPX30SC_CNT_DIR_UP		0
#define EPX30SC_CNT_DIR_DOWN	1

//
// Counter Control
//
#define EPX30SC_CNT_DISABLE	0
#define EPX30SC_CNT_ENABLE	1

//
// Counter Status
//
#define EPX30SC_CNT_OK		0
#define EPX30SC_CNT_OVF		1
#define EPX30SC_CNT_UDF		2

//
// Counter External Control
//
#define EPX30SC_CNT_EX_DISABLE	0
#define EPX30SC_CNT_EX_ENABLE	1

//
// Counter Latch Flag
//
#define EPX30SC_CNT_LAT_FALSE	0
#define EPX30SC_CNT_LAT_TRUE	1

//
// I/O Port
//
#define EPX30SC_PORT0	0
#define EPX30SC_PORT1	1
#define EPX30SC_PORT2	2
#define EPX30SC_PORT3	3

//
// Port Direction
//
#define EPX30SC_PORT_DIR_INPUT	0
#define EPX30SC_PORT_DIR_OUTPUT	1

#ifdef __cplusplus
extern "C" {
#endif

//
// Device Functions
//
EPX30SC_API int WINAPI EPX30SC_GetNumberOfDevices (int *Number);
EPX30SC_API int WINAPI EPX30SC_GetSerialNumber (int Index, int *SerialNumber);
EPX30SC_API int WINAPI EPX30SC_Open (EPX30SC_HANDLE *Handle);
EPX30SC_API int WINAPI EPX30SC_OpenBySerialNumber (int SerialNumber, EPX30SC_HANDLE *Handle);
EPX30SC_API int WINAPI EPX30SC_Close (EPX30SC_HANDLE Handle);

//
// Counter Functions
//
EPX30SC_API int WINAPI EPX30SC_SetCounterMode (EPX30SC_HANDLE Handle, BYTE Mode);
EPX30SC_API int WINAPI EPX30SC_GetCounterMode (EPX30SC_HANDLE Handle, BYTE *Mode);
EPX30SC_API int WINAPI EPX30SC_SetCounterDirection (EPX30SC_HANDLE Handle, BYTE Direction);
EPX30SC_API int WINAPI EPX30SC_GetCounterDirection (EPX30SC_HANDLE Handle, BYTE *Direction);
EPX30SC_API int WINAPI EPX30SC_SetCounterControl (EPX30SC_HANDLE Handle, BYTE Control);
EPX30SC_API int WINAPI EPX30SC_GetCounterControl (EPX30SC_HANDLE Handle, BYTE *Control);
EPX30SC_API int WINAPI EPX30SC_ResetCounter (EPX30SC_HANDLE Handle);
EPX30SC_API int WINAPI EPX30SC_GetCounterValue (EPX30SC_HANDLE Handle, int *Value);
EPX30SC_API int WINAPI EPX30SC_GetCounterStatus (EPX30SC_HANDLE Handle, BYTE *Status);
EPX30SC_API int WINAPI EPX30SC_GetCounterExControl (EPX30SC_HANDLE Handle, BYTE *Control);
EPX30SC_API int WINAPI EPX30SC_GetCounterLatchFlag (EPX30SC_HANDLE Handle, BYTE *Flag);
EPX30SC_API int WINAPI EPX30SC_GetCounterLatchValue (EPX30SC_HANDLE Handle, int *Value);

//
// I/O Port Functions
//
EPX30SC_API int WINAPI EPX30SC_SetPortDirection (EPX30SC_HANDLE Handle, BYTE Port, BYTE Direction);
EPX30SC_API int WINAPI EPX30SC_GetPortDirection (EPX30SC_HANDLE Handle, BYTE Port, BYTE *Direction);
EPX30SC_API int WINAPI EPX30SC_OutputPort (EPX30SC_HANDLE Handle, BYTE Port, BYTE Value);
EPX30SC_API int WINAPI EPX30SC_InputPort (EPX30SC_HANDLE Handle, BYTE Port, BYTE *Value);

#ifdef __cplusplus
}
#endif

#endif  /* EPX30SC_H */